==> zio-aws-docdb_2.13-5.17.150.1-sources.jar: zio/aws/docdb/model/StopDbClusterResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class StopDbClusterResponse(
    dbCluster: Option[zio.aws.docdb.model.DBCluster] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.StopDbClusterResponse = {
    import StopDbClusterResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.StopDbClusterResponse
      .builder()
      .optionallyWith(dbCluster.map(value => value.buildAwsValue()))(
        _.dbCluster
      )
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.StopDbClusterResponse.ReadOnly =
    zio.aws.docdb.model.StopDbClusterResponse.wrap(buildAwsValue())
}
object StopDbClusterResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.StopDbClusterResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.StopDbClusterResponse =
      zio.aws.docdb.model
        .StopDbClusterResponse(dbCluster.map(value => value.asEditable))
    def dbCluster: Option[zio.aws.docdb.model.DBCluster.ReadOnly]
    def getDbCluster
        : ZIO[Any, AwsError, zio.aws.docdb.model.DBCluster.ReadOnly] =
      AwsError.unwrapOptionField("dbCluster", dbCluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.StopDbClusterResponse
  ) extends zio.aws.docdb.model.StopDbClusterResponse.ReadOnly {
    override val dbCluster: Option[zio.aws.docdb.model.DBCluster.ReadOnly] =
      scala
        .Option(impl.dbCluster())
        .map(value => zio.aws.docdb.model.DBCluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.StopDbClusterResponse
  ): zio.aws.docdb.model.StopDbClusterResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-docdb_2.13-5.17.184.1-sources.jar: zio/aws/docdb/model/StopDbClusterResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class StopDbClusterResponse(
    dbCluster: Optional[zio.aws.docdb.model.DBCluster] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.StopDbClusterResponse = {
    import StopDbClusterResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.StopDbClusterResponse
      .builder()
      .optionallyWith(dbCluster.map(value => value.buildAwsValue()))(
        _.dbCluster
      )
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.StopDbClusterResponse.ReadOnly =
    zio.aws.docdb.model.StopDbClusterResponse.wrap(buildAwsValue())
}
object StopDbClusterResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.StopDbClusterResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.StopDbClusterResponse =
      zio.aws.docdb.model
        .StopDbClusterResponse(dbCluster.map(value => value.asEditable))
    def dbCluster: Optional[zio.aws.docdb.model.DBCluster.ReadOnly]
    def getDbCluster
        : ZIO[Any, AwsError, zio.aws.docdb.model.DBCluster.ReadOnly] =
      AwsError.unwrapOptionField("dbCluster", dbCluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.StopDbClusterResponse
  ) extends zio.aws.docdb.model.StopDbClusterResponse.ReadOnly {
    override val dbCluster: Optional[zio.aws.docdb.model.DBCluster.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbCluster())
        .map(value => zio.aws.docdb.model.DBCluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.StopDbClusterResponse
  ): zio.aws.docdb.model.StopDbClusterResponse.ReadOnly = new Wrapper(impl)
}
